==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterMetadataBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterMetadataBuilder extends ClusterMetadataFluentImpl<ClusterMetadataBuilder> implements VisitableBuilder<ClusterMetadata,ClusterMetadataBuilder>{
  public ClusterMetadataBuilder() {
    this(false);
  }
  public ClusterMetadataBuilder(Boolean validationEnabled) {
    this(new ClusterMetadata(), validationEnabled);
  }
  public ClusterMetadataBuilder(ClusterMetadataFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterMetadataBuilder(ClusterMetadataFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterMetadata(), validationEnabled);
  }
  public ClusterMetadataBuilder(ClusterMetadataFluent<?> fluent,ClusterMetadata instance) {
    this(fluent, instance, false);
  }
  public ClusterMetadataBuilder(ClusterMetadataFluent<?> fluent,ClusterMetadata instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAdminKubeconfigSecretRef(instance.getAdminKubeconfigSecretRef());
      fluent.withAdminPasswordSecretRef(instance.getAdminPasswordSecretRef());
      fluent.withClusterID(instance.getClusterID());
      fluent.withInfraID(instance.getInfraID());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterMetadataBuilder(ClusterMetadata instance) {
    this(instance,false);
  }
  public ClusterMetadataBuilder(ClusterMetadata instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAdminKubeconfigSecretRef(instance.getAdminKubeconfigSecretRef());
      this.withAdminPasswordSecretRef(instance.getAdminPasswordSecretRef());
      this.withClusterID(instance.getClusterID());
      this.withInfraID(instance.getInfraID());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterMetadataFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterMetadata build() {
    ClusterMetadata buildable = new ClusterMetadata(fluent.getAdminKubeconfigSecretRef(),fluent.getAdminPasswordSecretRef(),fluent.getClusterID(),fluent.getInfraID());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterMetadataBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterMetadataBuilder extends ClusterMetadataFluent<ClusterMetadataBuilder> implements VisitableBuilder<ClusterMetadata,ClusterMetadataBuilder>{
  public ClusterMetadataBuilder() {
    this(false);
  }
  public ClusterMetadataBuilder(Boolean validationEnabled) {
    this(new ClusterMetadata(), validationEnabled);
  }
  public ClusterMetadataBuilder(ClusterMetadataFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterMetadataBuilder(ClusterMetadataFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterMetadata(), validationEnabled);
  }
  public ClusterMetadataBuilder(ClusterMetadataFluent<?> fluent,ClusterMetadata instance) {
    this(fluent, instance, false);
  }
  public ClusterMetadataBuilder(ClusterMetadataFluent<?> fluent,ClusterMetadata instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterMetadata());

    if (instance != null) {
      fluent.withAdminKubeconfigSecretRef(instance.getAdminKubeconfigSecretRef());
      fluent.withAdminPasswordSecretRef(instance.getAdminPasswordSecretRef());
      fluent.withClusterID(instance.getClusterID());
      fluent.withInfraID(instance.getInfraID());
      fluent.withAdminKubeconfigSecretRef(instance.getAdminKubeconfigSecretRef());
      fluent.withAdminPasswordSecretRef(instance.getAdminPasswordSecretRef());
      fluent.withClusterID(instance.getClusterID());
      fluent.withInfraID(instance.getInfraID());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterMetadataBuilder(ClusterMetadata instance) {
    this(instance,false);
  }
  public ClusterMetadataBuilder(ClusterMetadata instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterMetadata());

    if (instance != null) {
      this.withAdminKubeconfigSecretRef(instance.getAdminKubeconfigSecretRef());
      this.withAdminPasswordSecretRef(instance.getAdminPasswordSecretRef());
      this.withClusterID(instance.getClusterID());
      this.withInfraID(instance.getInfraID());
      this.withAdminKubeconfigSecretRef(instance.getAdminKubeconfigSecretRef());
      this.withAdminPasswordSecretRef(instance.getAdminPasswordSecretRef());
      this.withClusterID(instance.getClusterID());
      this.withInfraID(instance.getInfraID());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterMetadataFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterMetadata build() {
    ClusterMetadata buildable = new ClusterMetadata(fluent.buildAdminKubeconfigSecretRef(),fluent.buildAdminPasswordSecretRef(),fluent.getClusterID(),fluent.getInfraID());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
